@@ -1,4 +1,4 @@
-package DBIx::Class::Schema::ResultSetNames 1.01;
+package DBIx::Class::Schema::ResultSetNames 1.02;
 use strict;
 use warnings;
 use base qw(DBIx::Class::Schema);
@@ -81,7 +81,7 @@ DBIx::Class::Schema::ResultSetNames - Create resultset accessors from table name
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
@@ -135,14 +135,6 @@ rows, and throw a warning. `find()` expects to return one row or undef, which is
 This doesn't tamper with relationship accessors in any way. If you have a table of Authors and a table of Books,
 the usual sort of `book($id)->author()`, and `author($id)->books()` relationship tools will still work just fine.
 
-=head1 NAME
-
-DBIx::Class::Schema::ResultSetNames - Add singluar and plural resultset accessors from schema class names
-
-=head1 VERSION
-
-Version 1.0.
-
 =head1 SEE ALSO
 
 =over 4
@@ -178,17 +170,6 @@ This software is copyright (c) 2021 by D Ruth Holloway.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 AUTHOR
-
-D Ruth Holloway <ruth@hiruthie.me>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021 by D Ruth Holloway.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
 __END__
